==> haskell-primitive-unaligned-0.1.1.2-38-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-I2XZfSseO1FJfIRqbGi26c
key:                  primitive-unaligned-0.1.1.2-I2XZfSseO1FJfIRqbGi26c
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  5613c26e02de4b4806940b5f17106b39
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.0.2/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.0.2/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-I2XZfSseO1FJfIRqbGi26c
depends:
    base-4.15.1.0 primitive-0.7.4.0-3MecjX0EG9nEyOtRD6f3ja

haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-unaligned-0.1.1.2-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-unaligned.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-unaligned
version:              0.1.1.2
visibility:           public
id:                   primitive-unaligned-0.1.1.2-1oXR9jiOV0QFec16vliUtc
key:                  primitive-unaligned-0.1.1.2-1oXR9jiOV0QFec16vliUtc
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           Andrew Martin <andrew.thaddeus@gmail.com>
author:               Andrew Martin
homepage:             https://github.com/haskell-primitive/primitive-unaligned
synopsis:             Unaligned access to primitive arrays
description:
    Unaligned access to primitive arrays. The offsets are given in bytes rather than elements.

category:             Data
abi:                  3ff5991aef83da5f71a79b572e3afb9a
exposed:              True
exposed-modules:      Data.Primitive.ByteArray.Unaligned
hidden-modules:       Data.Primitive.Unaligned.Mach
import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-unaligned-0.1.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-unaligned-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-unaligned
hs-libraries:         HSprimitive-unaligned-0.1.1.2-1oXR9jiOV0QFec16vliUtc
depends:              base-4.16.4.0 primitive-0.7.4.0-7EmETL08CQ5nNVujSkVxd
haddock-interfaces:
    /usr/share/doc/haskell-primitive-unaligned/html/primitive-unaligned.haddock

haddock-html:         /usr/share/doc/haskell-primitive-unaligned/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
